package com.example.shoppinglisting

import android.content.Intent
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.Menu
import android.view.MenuItem
import android.view.ViewGroup
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.example.shoppinglisting.ApiConnection.RetrofitConnection
import com.example.shoppinglisting.ApiConnection.RetrofitInterface
import com.example.shoppinglisting.Models.ShoppingLists
import com.example.shoppinglisting.databinding.ActivityMainBinding
import com.example.shoppinglisting.databinding.ItemShoppingListBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class MainActivity : AppCompatActivity(), RecyclerViewInterface {

    private lateinit var binding: ActivityMainBinding
    private lateinit var adapter: shoppingListRecyclerViewAdapter

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)

        setSupportActionBar(binding.toolbar)

        RetrofitInterface.getRetrofit(RetrofitConnection.getRetrofit()).GetAllLists(1)
            .enqueue(object : Callback<MutableList<ShoppingLists>> {
                override fun onResponse(
                    call: Call<MutableList<ShoppingLists>>,
                    response: Response<MutableList<ShoppingLists>>
                ) {
                    if (response.code() == 200) {
                        setRecyclerView(response.body()!!)
                    }
                }

                override fun onFailure(call: Call<MutableList<ShoppingLists>>, t: Throwable) {
                    Log.println(Log.ERROR, "АПИ", "не удалось установить связь")
                }
            })
    }

    override fun onCreateOptionsMenu(menu: Menu?): Boolean {
        menuInflater.inflate(R.menu.main_menu, menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        when (item.itemId) {
            R.id.action_delete -> {

            }
            R.id.action_select_all -> {

            }
            R.id.action_deselect_all -> {

            }
        }
        return true
    }

    private fun setRecyclerView(itemCollection: MutableList<ShoppingLists>) {
        binding.shoppingListsRecyclerView.layoutManager =
            LinearLayoutManager(this, LinearLayoutManager.VERTICAL, false)
        adapter = shoppingListRecyclerViewAdapter(itemCollection, this)
        binding.shoppingListsRecyclerView.adapter = adapter
    }

    override fun onItemClick(shoppingListName: String) {
        val intent = Intent(this, ShoppingListActivity::class.java)
        intent.putExtra("shoppingListName", shoppingListName)
        startActivity(intent)    }
}

class shoppingListRecyclerViewAdapter(var ShopListLists : MutableList<ShoppingLists>, var itemClickListener : RecyclerViewInterface) : RecyclerView.Adapter<shoppingListRecyclerViewViewHolder>()
{
    private val selectedItems = HashSet<Int>()
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): shoppingListRecyclerViewViewHolder {
        var layoutInflater : LayoutInflater = LayoutInflater.from(parent.context)
        var binding : ItemShoppingListBinding = ItemShoppingListBinding.inflate(layoutInflater)
        return shoppingListRecyclerViewViewHolder(binding)
    }

    override fun getItemCount(): Int {
        return ShopListLists.size
    }

    override fun onBindViewHolder(holder: shoppingListRecyclerViewViewHolder, position: Int) {
        holder.binding.textViewShoppingListName.text = ShopListLists[position].name

        holder.itemView.setOnClickListener {
            itemClickListener?.onItemClick(ShopListLists[position].name)
        }
    }
}

class shoppingListRecyclerViewViewHolder(var binding : ItemShoppingListBinding) : RecyclerView.ViewHolder(binding.root)

interface RecyclerViewInterface {
    fun onItemClick(shoppingListName: String)
}
