package com.example.shoppinglisting

import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.example.shoppinglisting.ApiConnection.RetrofitConnection
import com.example.shoppinglisting.ApiConnection.RetrofitInterface
import com.example.shoppinglisting.Models.ProductInShopList
import com.example.shoppinglisting.databinding.ActivityShoppingListBinding
import com.example.shoppinglisting.databinding.ItemProductInShopListBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class ShoppingListActivity : AppCompatActivity() {
    private lateinit var binding: ActivityShoppingListBinding
    private var shoppingListName: String = "-1"

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityShoppingListBinding.inflate(layoutInflater)
        setContentView(binding.root)

        // Получаем название списка покупок из интента
        shoppingListName = intent.getStringExtra("shoppingListName")!!

        // Настройка RecyclerView для отображения списка продуктов в списке покупок
        setupRecyclerView()
    }

    private fun setupRecyclerView() {
        // Инициализация RecyclerView
        val recyclerView = binding.productRecyclerView
        recyclerView.layoutManager = LinearLayoutManager(this)

        // Получение продуктов из API
        RetrofitInterface.getRetrofit(RetrofitConnection.getRetrofit())
            .GetAllProductInShopList(shoppingListName)
            .enqueue(object : Callback<MutableList<ProductInShopList>> {
                override fun onResponse(
                    call: Call<MutableList<ProductInShopList>>,
                    response: Response<MutableList<ProductInShopList>>
                ) {
                    if (response.isSuccessful) {
                        val products = response.body()
                        if (!products.isNullOrEmpty()) {
                            // Создаем адаптер для RecyclerView и передаем ему список продуктов
                            val adapter = ProductInShopListAdapter(products)
                            recyclerView.adapter = adapter
                        }
                    }
                }

                override fun onFailure(call: Call<MutableList<ProductInShopList>>, t: Throwable) {
                    Log.println(Log.ERROR, "API", "Не удалось соединиться с БД")
                }
            })
    }
}

class ProductInShopListAdapter(private val productList: List<ProductInShopList>) :
    RecyclerView.Adapter<ProductInShopListAdapter.ProductInShopListViewHolder>() {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ProductInShopListViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = ItemProductInShopListBinding.inflate(inflater, parent, false)
        return ProductInShopListViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ProductInShopListViewHolder, position: Int) {
        holder.bind(productList[position])
    }

    override fun getItemCount(): Int = productList.size

    inner class ProductInShopListViewHolder(private val binding: ItemProductInShopListBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(product: ProductInShopList) {
            binding.apply {
                // Привязка данных к представлению
                shopListIdTextView.text = "ID списка покупок: ${product.id_shop_list}"
                productInShopListIdTextView.text = "ID продукта: ${product.id_product}"
                quantityTextView.text = "Количество: ${product.quantity}"
                completedTextView.text = "Куплено: ${product.completed}"
            }
        }
    }
}
