package com.example.shoppinglisting

import android.content.Intent
import android.os.Bundle
import android.widget.Toast
import androidx.activity.enableEdgeToEdge
import androidx.appcompat.app.AppCompatActivity
import androidx.core.view.ViewCompat
import androidx.core.view.WindowInsetsCompat
import com.example.shoppinglisting.ApiConnection.APIInterface
import com.example.shoppinglisting.ApiConnection.RetrofitConnection
import com.example.shoppinglisting.ApiConnection.RetrofitInterface
import com.example.shoppinglisting.databinding.ActivityRegistrationBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class activity_registration : AppCompatActivity() {
    private lateinit var binding: ActivityRegistrationBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityRegistrationBinding.inflate(layoutInflater)
        setContentView(binding.root)

        // Обработка нажатия кнопки регистрации
        binding.registerButton.setOnClickListener {
            val username = binding.usernameEditText.text.toString()
            val password = binding.passwordEditText.text.toString()

            // Проверка, что поля не пустые
            if (username.isNotEmpty() && password.isNotEmpty()) {
                registerUser(username, password)
            } else {
                Toast.makeText(this, "Пожалуйста, заполните все поля", Toast.LENGTH_SHORT).show()
            }
        }

        // Обработка нажатия текста "Уже есть аккаунт? Войти"
        binding.loginTextView.setOnClickListener {
            // Переход к активности входа
            startActivity(Intent(this, activity_login::class.java))
            finish()
        }
    }

    private fun registerUser(username: String, password: String) {
        // Выполнение запроса на регистрацию пользователя через Retrofit
        val retrofit = RetrofitConnection.getRetrofit()
        val apiInterface = RetrofitInterface.getRetrofit(retrofit)
        apiInterface.AddNewUser(username, password).enqueue(object : Callback<Void> {
            override fun onResponse(call: Call<Void>, response: Response<Void>) {
                if (response.isSuccessful && response.code() == 200) {
                    // Пользователь успешно зарегистрирован, показываем сообщение об успешной регистрации
                    Toast.makeText(applicationContext, "Регистрация прошла успешно", Toast.LENGTH_SHORT).show()
                    // Переход к активности входа
                    startActivity(Intent(applicationContext, activity_login::class.java))
                    finish()
                } else {
                    // Ошибка при регистрации пользователя
                    Toast.makeText(applicationContext, "Ошибка при регистрации пользователя", Toast.LENGTH_SHORT).show()
                }
            }

            override fun onFailure(call: Call<Void>, t: Throwable) {
                // Ошибка при выполнении запроса
                Toast.makeText(applicationContext, "Ошибка при выполнении запроса", Toast.LENGTH_SHORT).show()
            }
        })
    }
}